Skip to content
New issue

Have a question about this project? Sign up for a free GitHub account to open an issue and contact its maintainers and the community.

By clicking “Sign up for GitHub”, you agree to our terms of service and privacy statement. We’ll occasionally send you account related emails.

Already on GitHub? Sign in to your account

[PATCH] Fix typos (spelling errors) in cpan/Unicode*. #11001

Closed
p5pRT opened this issue Jan 7, 2011 · 4 comments
Closed

[PATCH] Fix typos (spelling errors) in cpan/Unicode*. #11001

p5pRT opened this issue Jan 7, 2011 · 4 comments

Comments

@p5pRT
Copy link

p5pRT commented Jan 7, 2011

Migrated from rt.perl.org#81876 (status was 'resolved')

Searchable as RT81876$

@p5pRT
Copy link
Author

p5pRT commented Jan 7, 2011

From @pjacklam


cpan/Unicode-Collate/Changes | 4 ++--
cpan/Unicode-Collate/Collate.pm | 16 ++++++++--------
cpan/Unicode-Normalize/Changes | 2 +-
cpan/Unicode-Normalize/Normalize.pm | 2 +-
cpan/Unicode-Normalize/mkheader | 2 +-
5 files changed, 13 insertions(+), 13 deletions(-)

Inline Patch
diff --git a/cpan/Unicode-Collate/Changes b/cpan/Unicode-Collate/Changes
index ca9be54..b805091 100644
--- a/cpan/Unicode-Collate/Changes
+++ b/cpan/Unicode-Collate/Changes
@@ -24,7 +24,7 @@ Revision history for Perl module Unicode::Collate.
     - 12 compat. ideographs (e.g. U+FA0E) are treated as unified ideographs.
      (though DUCET also does it, now Unicode::Collate does it without DUCET.)
     - added t/compatui.t.
-    ! Ideographs Ext.B (U+20000..U+2A6D6) can be overrided with UCA_Version 8.
+    ! Ideographs Ext.B (U+20000..U+2A6D6) can be overridden with UCA_Version 8.
       This is a long-standing behavior from Unicode::Collate 0.11 to 0.63.
       A wrong fix at 0.64 should be abandoned.
 
@@ -178,7 +178,7 @@ Revision history for Perl module Unicode::Collate.
       in XSUB. Pure Perl is also supported.
 
 0.30  Mon Oct 13 21:26:37 2003
-    - fix: Completely ignorable in table should be able to be overrided
+    - fix: Completely ignorable in table should be able to be overridden
       by non-ignorable in entry.
     - fix: Maximum length for contraction must not be shortened
       by a shorter contraction following in table and/or entry.
diff --git a/cpan/Unicode-Normalize/Changes b/cpan/Unicode-Normalize/Changes
index 893a604..a6d74d2 100644
--- a/cpan/Unicode-Normalize/Changes
+++ b/cpan/Unicode-Normalize/Changes
@@ -60,7 +60,7 @@ Revision history for Perl extension Unicode::Normalize.
     - XSUB: even if string contains a malformed, "short" Unicode character,
       decompose() and reorder() will be safe. Garbage will be no longer added.
     - added null.t and short.t.
-    - now truely added illegal.t (in 0.27, forgot to change MANIFEST).
+    - now truly added illegal.t (in 0.27, forgot to change MANIFEST).
 
 0.27  Sun Nov 16 13:16:21 2003
     - Illegal code points (surrogate and noncharacter) will be allowed
diff --git a/cpan/Unicode-Normalize/Normalize.pm b/cpan/Unicode-Normalize/Normalize.pm
index ab895aa..4bebae5 100644
--- a/cpan/Unicode-Normalize/Normalize.pm
+++ b/cpan/Unicode-Normalize/Normalize.pm
@@ -34,7 +34,7 @@ our %EXPORT_TAGS = (
 );
 
 ##
-## utilites for tests
+## utilities for tests
 ##
 
 sub pack_U {
diff --git a/cpan/Unicode-Normalize/mkheader b/cpan/Unicode-Normalize/mkheader
index b6d153c..4cd7754 100644
--- a/cpan/Unicode-Normalize/mkheader
+++ b/cpan/Unicode-Normalize/mkheader
@@ -90,7 +90,7 @@ sub decomposeHangul {
     return wantarray ? @ret : pack_U(@ret);
 }
 
-########## getting full decomposion ##########
+########## getting full decomposition ##########
 {
     my($f, $fh);
     foreach my $d (@INC) {
diff --git a/cpan/Unicode-Collate/Collate.pm b/cpan/Unicode-Collate/Collate.pm
index b337b6f..3531fb1 100644
--- a/cpan/Unicode-Collate/Collate.pm
+++ b/cpan/Unicode-Collate/Collate.pm
@@ -692,7 +692,7 @@ sub getWt
 			$map->{$contract} and @decH = ($contract, $decH[2]);
 		    }
 		    # even if V's ignorable, LT contraction is not supported.
-		    # If such a situatution were required, NFD should be used.
+		    # If such a situation were required, NFD should be used.
 		}
 		if (@decH == 3 && $max->{$decH[1]}) {
 		    my $contract = join(CODE_SEP, @decH[1,2]);
@@ -1023,7 +1023,7 @@ sub _eqArray($$$)
     my $lev = shift;
 
     for my $g (0..@$substr-1){
-	# Do the $g'th graphemes have the same number of AV weigths?
+	# Do the $g'th graphemes have the same number of AV weights?
 	return if @{ $source->[$g] } != @{ $substr->[$g] };
 
 	for my $w (0..@{ $substr->[$g] }-1) {
@@ -1321,7 +1321,7 @@ The following tracking versions are supported.  The default is 20.
 
 Note: Recent UTS #10 renames "Tracking Version" to "Revision."
 
 * Noncharacters (e.g. U+FFFF) are not ignored, and can be overrided
 since C<UCA_Version> 22.
 
 * Fully ignorable characters were ignored, and would not interrupt
@@ -1359,7 +1359,7 @@ forwards at all the levels.
 
 If the same character (or a sequence of characters) exists
 in the collation element table through C<table>,
-mapping to collation elements is overrided.
+mapping to collation elements is overridden.
 If it does not exist, the mapping is defined additionally.
 
     entry => <<'ENTRY', # for DUCET v4.0.0 (allkeys-4.0.0.txt)
@@ -1536,7 +1536,7 @@ those in the CJK Unified Ideographs Extension A etc.
     Ext.D (U+2B740..U+2B81D) if UCA_Version is 22 or greater.
 
 Through C<overrideCJK>, ordering of CJK unified ideographs (including
-extensions) can be overrided.
+extensions) can be overridden.
 
 ex. CJK unified ideographs in the JIS code point order.
 
@@ -1579,7 +1579,7 @@ in C<table> or C<entry> is still valid.
 B<Note:> In addition to them, 12 CJK compatibility ideographs (C<U+FA0E>,
 C<U+FA0F>, C<U+FA11>, C<U+FA13>, C<U+FA14>, C<U+FA1F>, C<U+FA21>, C<U+FA23>,
 C<U+FA24>, C<U+FA27>, C<U+FA28>, C<U+FA29>) are also treated as CJK unified
-ideographs. But they can't be overrided via C<overrideCJK> when you use
+ideographs. But they can't be overridden via C<overrideCJK> when you use
 DUCET, as the table includes weights for them. C<table> or C<entry> has
 priority over C<overrideCJK>.
 
@@ -1589,7 +1589,7 @@ priority over C<overrideCJK>.
 
 By default, Hangul syllables are decomposed into Hangul Jamo,
 even if C<(normalization =E<gt> undef)>.
-But the mapping of Hangul syllables may be overrided.
+But the mapping of Hangul syllables may be overridden.
 
 This parameter works like C<overrideCJK>, so see there for examples.
 
@@ -1750,7 +1750,7 @@ this parameter doesn't work validly.
 
 This key allows to variable weighting for variable collation elements,
 which are marked with an ASTERISK in the table
-(NOTE: Many punction marks and symbols are variable in F<allkeys.txt>).
+(NOTE: Many punctuation marks and symbols are variable in F<allkeys.txt>).
 
    variable => 'blanked', 'non-ignorable', 'shifted', or 'shift-trimmed'.
 
@@ -1321,7 +1321,7 @@ The following tracking versions are supported.  The default is 20.
 Note: Recent UTS #10 renames "Tracking Version" to "Revision."
 
-* Noncharacters (e.g. U+FFFF) are not ignored, and can be overrided
+* Noncharacters (e.g. U+FFFF) are not ignored, and can be overridden
 since C<UCA_Version> 22.
 
-- 
1.7.3.3

@p5pRT
Copy link
Author

p5pRT commented Jan 8, 2011

From BQW10602@nifty.com

On Thu, 06 Jan 2011 23​:11​:41 -0800
(Peter J. Acklam) (via RT) <perlbug-followup@​perl.org> wrote​:

# New Ticket Created by (Peter J. Acklam)
# Please include the string​: [perl #81876]
# in the subject line of all future correspondence about this issue.
# <URL​: http​://rt.perl.org/rt3/Ticket/Display.html?id=81876 >

---
cpan/Unicode-Collate/Changes | 4 ++--
cpan/Unicode-Collate/Collate.pm | 16 ++++++++--------
cpan/Unicode-Normalize/Changes | 2 +-
cpan/Unicode-Normalize/Normalize.pm | 2 +-
cpan/Unicode-Normalize/mkheader | 2 +-
5 files changed, 13 insertions(+), 13 deletions(-)

Thanks. applied to the next release of these modules.

SADAHIRO Tomoyuki

@p5pRT
Copy link
Author

p5pRT commented Jan 8, 2011

The RT System itself - Status changed from 'new' to 'open'

@p5pRT
Copy link
Author

p5pRT commented Jan 8, 2011

@iabyn - Status changed from 'open' to 'resolved'

Sign up for free to join this conversation on GitHub. Already have an account? Sign in to comment
Projects
None yet
Development

No branches or pull requests

1 participant